# Installation
> `npm install --save @types/command-line-args`

# Summary
This package contains type definitions for command-line-args (https://github.com/75lb/command-line-args).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/command-line-args.

### Additional Details
 * Last updated: Tue, 07 Nov 2023 15:11:36 GMT
 * Dependencies: none

# Credits
These definitions were written by [Lloyd Brookes](https://github.com/75lb).
